<?php  if ( ! defined('BASEPATH')) exit('No direct script access allowed');
/**
 * Webservice Grid Matrix Relationship
 *
 * @package		webservice
 * @category	Modules
 * @author		Rein de Vries <info@reinos.nl>
 * @link		http://reinos.nl/add-ons/webservice
 * @license  	http://reinos.nl/add-ons/commercial-license
 * @copyright 	Copyright (c) 2016 Reinos.nl Internet Media
 */

// ------------------------------------------------------------------------

class Webservice_morematrixrelations_ext {

    var $name           = 'Webservice moreMatrixRelations';
    var $version        = '1.3.0';
    var $description    = 'Webservice Extension : convert the entry_id of a moreMatrixRelations field in an entry';
    var $settings_exist = 'n';
    var $docs_url       = 'http://reinos.nl/add-ons/webservice/docs';
    var $settings       = array();

    /**
     * Constructor
     *
     * @param   mixed   Settings array or empty string if none exist.
     */
    function __construct($settings = '')
    {
        $this->settings = $settings;
    }

    /**
    * Activate Extension
    *
    * This function enters the extension into the exp_extensions table
    *
    * @see http://codeigniter.com/user_guide/database/index.html for
    * more information on the db class.
    *
    * @return void
    */
    function activate_extension()
    {
        $data = array(
            'class'     => __CLASS__,
            'method'    => 'parse_data',
            'hook'      => 'webservice_read_entry_matrix',
            'settings'  => serialize($this->settings),
            'priority'  => 10,
            'version'   => $this->version,
            'enabled'   => 'y'
        );

        ee()->db->insert('extensions', $data);
    }

    /**
    * Update Extension
    *
    * This function performs any necessary db updates when the extension
    * page is visited
    *
    * @return  mixed   void on update / false if none
    */
    function update_extension($current = '')
    {
        if ($current == '' OR $current == $this->version)
        {
            return FALSE;
        }

        ee()->db->where('class', __CLASS__);
        ee()->db->update(
            'extensions',
            array('version' => $this->version)
        );
    }

    /**
    * Disable Extension
    *
    * This method removes information from the exp_extensions table
    *
    * @return void
    */
    function disable_extension()
    {
        ee()->db->where('class', __CLASS__);
        ee()->db->delete('extensions');
    }

    /**
     * Parse relationship
     *
     * @param null $value
     * @param array $col_settings
     * @return return array
     */
    function parse_data($value = null, $col_settings = array())
    {
        //morematrixrelations
        if($col_settings['col_type'] == 'morematrixrelations')
        {
           if($value != '')
           {
               $entry = array();
               foreach(explode('|', $value) as $entry_id)
               {
                   $entry[] = ee()->webservice_lib->get_entry($value, array('*'), true);
               }

               $value = $entry;
           }
        }

        return $value;
    }
}